#include <Wire.h>
#include <Servo.h>

#define SDA_PIN PB0
#define SCL_PIN PB2
#define LED_PIN PB3
#define SERVO_PIN PB4

#define I2C_DEV_ADDR 0x07
#define INVALID -1
#define LEFT  0
#define RIGHT 1

/* variables to manage the servo*/
Servo servo;
int pos_servo = 90;
int min_servo = 0;
int max_servo = 180;
int speed_move = 3;

int delay_t = 500;

void blink_led(){
  digitalWrite(LED_PIN, HIGH);
  delay(200);
  digitalWrite(LED_PIN, LOW);
  delay(200);
}
void blink_led_n(int n){
  for(int i = 0; i < n; ++i){
    blink_led();
  }
}

void setup_servo(){
  //define pinOut from microcontroller
  servo.attach(SERVO_PIN);
  //move servo to initial position.
  servo.write(pos_servo);
}

void move_servo(int dir){
  int new_pos = pos_servo;
  if(dir == LEFT){
    new_pos = pos_servo - speed_move;
    if(new_pos >= min_servo) servo.write(new_pos);
    else blink_led_n(2);
  }
  else if(dir == RIGHT){
    new_pos = pos_servo + speed_move;
    if(new_pos <= max_servo) servo.write(new_pos);
    else blink_led_n(3);
  }
  else{
    blink_led_n(4);
  }
  pos_servo = new_pos;
}

void setup() {
  pinMode(LED_PIN, OUTPUT);
  Wire.begin();        // join i2c bus (address optional for master)
  setup_servo();
  blink_led_n(3);
  delay(1000);
}

void loop() {
  Wire.requestFrom(I2C_DEV_ADDR, 1);    // request 1 bytes from slave device #9

  while (Wire.available()) { // slave may send less than requested
    long i2c_value = Wire.read(); // receive a byte as character
    move_servo(i2c_value);
    blink_led();
  }
  delay(500);
}
