#include "wifiFabAcademy.h"
#include <Wire.h>

#define I2C_DEV_ADDR 0x07
#define INVALID -1
#define LEFT  0
#define RIGHT 1

int nextMove = INVALID;

void setup() {
  Serial.begin(115200);           // start serial for output
  Serial.println("init setup...");
  
  setup_wifi();
  setup_httpServer();
  
  Wire.begin(I2C_DEV_ADDR);                // join i2c bus with address #9
  Wire.onRequest(requestEvent); // register event
  
  Serial.println("Servo ESP32 I2C slave sender ready.");
}

void loop() {
  // Check if a client has connected
  WiFiClient client = httpServer.available();
  if (!client) {
    return;
  }

  // Wait until the client sends some data
  Serial.println("new client...");
  while(!client.available()){
    delay(1000);
  }
  String request = client.readStringUntil('\r');

  Serial.print("Value read from wifi: ");
  Serial.println(request);
  client.flush();

  String msg;
  if (request.indexOf("/servoA/left") != -1)  {
    msg = "Move servo left...";
    nextMove = LEFT;
  }
  else if (request.indexOf("/servoA/right") != -1)  {
    msg = "Move servo right...";
    nextMove = RIGHT;
  }
  else {
    msg = "Unknown request [" + request + "]";
    nextMove = INVALID;
  }
  Serial.print("Last move: ");
  Serial.println(msg);
  countPlusPlus();
  // Return the response
  sendAckResponse(client, msg);
 
  delay(1);
  Serial.println("Client disonnected");
  Serial.println("");
  
  delay(100);
}

// function that executes whenever data is requested by master
// this function is registered as an event, see setup()
void requestEvent() {
  Wire.write(nextMove); // send int value received by MQTT or -1
  // as expected by master
  Serial.printf("Info sent I2C: %d\n", nextMove);
}
